==> dav1d-0.1.0.tar.xz: dav1d-0.1.0/src/x86/cpu.h <==
/*
 * Copyright © 2018, VideoLAN and dav1d authors
 * Copyright © 2018, Two Orioles, LLC
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __DAV1D_SRC_X86_CPU_H__
#define __DAV1D_SRC_X86_CPU_H__

enum CpuFlags {
    DAV1D_X86_CPU_FLAG_SSE = 1 << 0,
    DAV1D_X86_CPU_FLAG_SSE2 = 1 << 1,
    DAV1D_X86_CPU_FLAG_SSE3 = 1 << 2,
    DAV1D_X86_CPU_FLAG_SSSE3 = 1 << 3,
    DAV1D_X86_CPU_FLAG_SSE41 = 1 << 4,
    DAV1D_X86_CPU_FLAG_SSE42 = 1 << 5,
    DAV1D_X86_CPU_FLAG_AVX = 1 << 6,
    DAV1D_X86_CPU_FLAG_AVX2 = 1 << 7,
    DAV1D_X86_CPU_FLAG_AVX512 = 1 << 8, /* F + CD + BW + DQ + VL */
};

unsigned dav1d_get_cpu_flags_x86(void);

#endif /* __DAV1D_SRC_X86_CPU_H__ */

==> dav1d-0.3.1.tar.xz: dav1d-0.3.1/src/x86/cpu.h <==
/*
 * Copyright © 2018, VideoLAN and dav1d authors
 * Copyright © 2018, Two Orioles, LLC
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DAV1D_SRC_X86_CPU_H
#define DAV1D_SRC_X86_CPU_H

enum CpuFlags {
    DAV1D_X86_CPU_FLAG_SSE = 1 << 0,
    DAV1D_X86_CPU_FLAG_SSE2 = 1 << 1,
    DAV1D_X86_CPU_FLAG_SSE3 = 1 << 2,
    DAV1D_X86_CPU_FLAG_SSSE3 = 1 << 3,
    DAV1D_X86_CPU_FLAG_SSE41 = 1 << 4,
    DAV1D_X86_CPU_FLAG_SSE42 = 1 << 5,
    DAV1D_X86_CPU_FLAG_AVX = 1 << 6,
    DAV1D_X86_CPU_FLAG_AVX2 = 1 << 7,
    DAV1D_X86_CPU_FLAG_AVX512 = 1 << 8, /* F + CD + BW + DQ + VL */
};

unsigned dav1d_get_cpu_flags_x86(void);

#endif /* DAV1D_SRC_X86_CPU_H */
